==> fltk-docs-1.3.9-1-x86_64.pkg.tar.zst: usr/share/doc/fltk/html/classFl__Help__View.js <==
var classFl__Help__View =
[
    [ "Fl_Help_View", "classFl__Help__View.html#af3f2935801fe289f17616f7a58b82ea9", null ],
    [ "~Fl_Help_View", "classFl__Help__View.html#ac12a07242886c1cdd811de20ce3a3447", null ],
    [ "clear_selection", "classFl__Help__View.html#a6ad8e324f62c8f22c335a8860680e7cb", null ],
    [ "directory", "classFl__Help__View.html#a96c6f5e1432a40b115083bffe695dc56", null ],
    [ "draw", "classFl__Help__View.html#a10187486039cb371551c7f65e137b68f", null ],
    [ "filename", "classFl__Help__View.html#a3cd272dbe3b1e8c7fc3bfad568b7a5b5", null ],
    [ "find", "classFl__Help__View.html#a50ad770ff85426da7eb7859f6b747187", null ],
    [ "handle", "classFl__Help__View.html#af56e5586b3b97243a64773d0b893d04d", null ],
    [ "leftline", "classFl__Help__View.html#afcb8ef0eb0118ca89487d2917cbae94c", null ],
    [ "leftline", "classFl__Help__View.html#a83f502b7e8e1abe07806e2a693e42a25", null ],
    [ "link", "classFl__Help__View.html#a6407d2a4cc890b51f303ebf56450588e", null ],
    [ "load", "classFl__Help__View.html#a70786a7db2d6a049c673b8bcd4a095d8", null ],
    [ "resize", "classFl__Help__View.html#ab5ef730c30f06bf24a55ff70c6cdd490", null ],
    [ "scrollbar_size", "classFl__Help__View.html#a4b04f0fbf9a2af3cd631000517931e56", null ],
    [ "scrollbar_size", "classFl__Help__View.html#a8fb7811d9989f93ab4557503415f197b", null ],
    [ "select_all", "classFl__Help__View.html#aa7d1a77e47ca1011cd5c9ac679a450fb", null ],
    [ "size", "classFl__Help__View.html#a329ae206394833dd2fb7a08c197399f0", null ],
    [ "textcolor", "classFl__Help__View.html#ae9888bd1084bc52f60d903021fb13e7a", null ],
    [ "textcolor", "classFl__Help__View.html#a2b547cd7eb0091b33cf8b0205090779c", null ],
    [ "textfont", "classFl__Help__View.html#a231e326eadb6635dd233990c00f0b2f5", null ],
    [ "textfont", "classFl__Help__View.html#adc935fb61238a2746d9f3cba641b0cb2", null ],
    [ "textsize", "classFl__Help__View.html#a66b2e6d44dbcb2be026f73c5c1c1d15c", null ],
    [ "textsize", "classFl__Help__View.html#a96d954c3cb3506c3bace2a27ab89a9e7", null ],
    [ "title", "classFl__Help__View.html#a5a3652ad81c74149546cfcf93e17b855", null ],
    [ "topline", "classFl__Help__View.html#ad6444c1ba49103ba71fdfe05eed68751", null ],
    [ "topline", "classFl__Help__View.html#a81559cdf5d5380fd1fc3d548b5fd1f4c", null ],
    [ "topline", "classFl__Help__View.html#a130b631f4cdc5a5e80a95bb19382a9ba", null ],
    [ "value", "classFl__Help__View.html#a872cb5d758ae805bc25f73b66dbe18c4", null ],
    [ "value", "classFl__Help__View.html#adefe614a70fbe249dd9cb47278c1cb02", null ]
];

==> fltk-docs-1.4.4-3-x86_64.pkg.tar.zst: usr/share/doc/fltk/html/classFl__Help__View.js <==
var classFl__Help__View =
[
    [ "Fl_Help_View", "classFl__Help__View.html#af3f2935801fe289f17616f7a58b82ea9", null ],
    [ "~Fl_Help_View", "classFl__Help__View.html#ac12a07242886c1cdd811de20ce3a3447", null ],
    [ "clear_selection", "classFl__Help__View.html#a6ad8e324f62c8f22c335a8860680e7cb", null ],
    [ "copy", "classFl__Help__View.html#a0ad3eeca8ff544fa1bb560a0f5e3900e", null ],
    [ "directory", "classFl__Help__View.html#a96c6f5e1432a40b115083bffe695dc56", null ],
    [ "draw", "classFl__Help__View.html#a0d7a18c7485a56d57a3f191f8acdfaf5", null ],
    [ "filename", "classFl__Help__View.html#a3cd272dbe3b1e8c7fc3bfad568b7a5b5", null ],
    [ "find", "classFl__Help__View.html#a50ad770ff85426da7eb7859f6b747187", null ],
    [ "handle", "classFl__Help__View.html#a8f676e61e6ab6e1714d6c4ee3e353163", null ],
    [ "hscrollbar", "classFl__Help__View.html#aca0d55035e32e45caf71e7018692bb66", null ],
    [ "leftline", "classFl__Help__View.html#afcb8ef0eb0118ca89487d2917cbae94c", null ],
    [ "leftline", "classFl__Help__View.html#a83f502b7e8e1abe07806e2a693e42a25", null ],
    [ "link", "classFl__Help__View.html#a6407d2a4cc890b51f303ebf56450588e", null ],
    [ "load", "classFl__Help__View.html#a70786a7db2d6a049c673b8bcd4a095d8", null ],
    [ "resize", "classFl__Help__View.html#a907e4e86a19932c679f89c02142d6872", null ],
    [ "scrollbar", "classFl__Help__View.html#a927082f3ce605be024d4754b06f3aba5", null ],
    [ "scrollbar_size", "classFl__Help__View.html#a4b04f0fbf9a2af3cd631000517931e56", null ],
    [ "scrollbar_size", "classFl__Help__View.html#a8fb7811d9989f93ab4557503415f197b", null ],
    [ "select_all", "classFl__Help__View.html#aa7d1a77e47ca1011cd5c9ac679a450fb", null ],
    [ "size", "classFl__Help__View.html#a329ae206394833dd2fb7a08c197399f0", null ],
    [ "text_selected", "classFl__Help__View.html#a5a6118ed4a66d5269ca57a60fad81aec", null ],
    [ "textcolor", "classFl__Help__View.html#ae9888bd1084bc52f60d903021fb13e7a", null ],
    [ "textcolor", "classFl__Help__View.html#a2b547cd7eb0091b33cf8b0205090779c", null ],
    [ "textfont", "classFl__Help__View.html#a231e326eadb6635dd233990c00f0b2f5", null ],
    [ "textfont", "classFl__Help__View.html#adc935fb61238a2746d9f3cba641b0cb2", null ],
    [ "textsize", "classFl__Help__View.html#a66b2e6d44dbcb2be026f73c5c1c1d15c", null ],
    [ "textsize", "classFl__Help__View.html#a96d954c3cb3506c3bace2a27ab89a9e7", null ],
    [ "title", "classFl__Help__View.html#a5a3652ad81c74149546cfcf93e17b855", null ],
    [ "topline", "classFl__Help__View.html#ad6444c1ba49103ba71fdfe05eed68751", null ],
    [ "topline", "classFl__Help__View.html#a81559cdf5d5380fd1fc3d548b5fd1f4c", null ],
    [ "topline", "classFl__Help__View.html#a130b631f4cdc5a5e80a95bb19382a9ba", null ],
    [ "value", "classFl__Help__View.html#a872cb5d758ae805bc25f73b66dbe18c4", null ],
    [ "value", "classFl__Help__View.html#adefe614a70fbe249dd9cb47278c1cb02", null ]
];
